@@ -1,22 +1,19 @@
 #
 # This file is part of Log-Dispatch-Email-EmailSender
 #
-# This software is copyright (c) 2013 by Loïc TROCHET.
+# This software is copyright (c) 2013 by losyme.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 package Log::Dispatch::Email::EmailSender;
-{
-  $Log::Dispatch::Email::EmailSender::VERSION = '0.130020';
-}
 # ABSTRACT: Subclass of Log::Dispatch::Email that uses Email::Sender
-
+$Log::Dispatch::Email::EmailSender::VERSION = '0.150390';
 use strict;
 use warnings;
 
 use Params::Validate qw(validate SCALAR);
-use Email::Sender::Simple qw(sendmail);
+use Email::Sender::Simple qw(try_to_sendmail);
 use Email::Simple;
 use Email::Simple::Creator;
 use Email::Sender::Transport::SMTP;
@@ -75,7 +72,7 @@ sub send_email
     $args = {transport => Email::Sender::Transport::SMTP->new({host => $self->{smtp}, port => $self->{port}})}
         if exists $self->{smtp};
 
-    sendmail($email, $args);
+    try_to_sendmail($email, $args);
 }
 
 1;
@@ -84,13 +81,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Email::EmailSender - Subclass of Log::Dispatch::Email that uses Email::Sender
 
 =head1 VERSION
 
-version 0.130020
+version 0.150390
 
 =head1 SYNOPSIS
 
@@ -167,15 +166,13 @@ L<Log::Dispatch::Email::MailSender>
 
 L<Log::Dispatch::Email::MailSendmail>
 
-=encoding utf8
-
 =head1 AUTHOR
 
-Loïc TROCHET <losyme@cpan.org>
+losyme <losyme@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Loïc TROCHET.
+This software is copyright (c) 2013 by losyme.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
